@@ -17,7 +17,6 @@ class HardwareType(str, Enum):
     T4 = "T4"
     A100_80G = "A100 80GB GCP"
     A100_40G = "A100 40GB GCP"
-    A6000 = "RTX A6000"
     CPU = "CPU"
     EPYC = "EPYC"
     XAVIER = "Jetson Xavier"
@@ -95,7 +94,6 @@ class HardwareMachineModel(str, Enum):
     NUC_TIGER_LAKE = HardwareType.NUC_TIGER_LAKE.value
     A100_80G = HardwareType.A100_80G.value
     A100_40G = HardwareType.A100_40G.value
-    A6000 = HardwareType.A6000.value
     HAILO8 = HardwareType.HAILO8.value
     AMBARELLA = HardwareType.AMBARELLA.value
     APPLE_IPHONE_A11 = HardwareType.APPLE_IPHONE_A11.value
@@ -128,7 +126,6 @@ class MapHardwareTypeToFamily(str, Enum):
     T4 = InferenceHardware.GPU.value
     A100_80G = InferenceHardware.GPU.value
     A100_40G = InferenceHardware.GPU.value
-    A6000 = InferenceHardware.GPU.value
     NANO = InferenceHardware.GPU.value
     XAVIER = InferenceHardware.GPU.value
     XAVIER_AGX = InferenceHardware.GPU.value
@@ -158,7 +155,6 @@ class MapHardwareTypeToInferyVersion(str, Enum):
     T4 = InferyVersion.GPU.value
     A100_80G = InferyVersion.GPU.value
     A100_40G = InferyVersion.GPU.value
-    A6000 = InferyVersion.GPU.value
 
     # Jetsons
     NANO = InferyVersion.JETSON_PY36.value
@@ -195,7 +191,6 @@ class HardwareTaint(str, Enum):
     T4 = "nvidia.com/t4gpu"
     A100_80G = UNKNOWN
     A100_40G = UNKNOWN
-    A6000 = UNKNOWN
     NANO = "nvidia.com/jetson-nano"
     XAVIER = "nvidia.com/jetson-xavier"
     XAVIER_AGX = "nvidia.com/jetson-xavier-agx"
@@ -215,7 +210,6 @@ class HardwareLabel(str, Enum):
     T4 = "nvidia-tesla-t4"
     A100_80G = UNKNOWN
     A100_40G = UNKNOWN
-    A6000 = UNKNOWN
     M60 = "nvidia-m60"
     NANO = "nvidia-jetson-nano"
     XAVIER = "nvidia-jetson-xavier"
@@ -236,7 +230,6 @@ class MapHardwareTypeToVendor(str, Enum):
     T4 = HardwareVendor.NVIDIA.value
     A100_80G = HardwareVendor.NVIDIA.value
     A100_40G = HardwareVendor.NVIDIA.value
-    A6000 = HardwareVendor.NVIDIA.value
     EPYC = HardwareVendor.AMD.value
     NANO = HardwareVendor.NVIDIA.value
     XAVIER = HardwareVendor.NVIDIA.value
@@ -272,7 +265,6 @@ class MapHardwareTypeToDefaultBatchSizeList(list, Enum):
     T4 = get_enum_values(BatchSize)
     A100_80G = get_enum_values(BatchSize)
     A100_40G = get_enum_values(BatchSize)
-    A6000 = get_enum_values(BatchSize)
     EPYC = get_enum_values(BatchSize)
     NANO = get_enum_values(BatchSizeEdge)
     XAVIER = get_enum_values(BatchSizeEdge)
@@ -320,7 +312,6 @@ class MapHardwareTypeToGroup(str, Enum):
     T4 = HardwareGroup.GPU.value
     A100_80G = HardwareGroup.GPU.value
     A100_40G = HardwareGroup.GPU.value
-    A6000 = HardwareGroup.GPU.value
 
     XAVIER = HardwareGroup.COMMERCIAL_EDGE.value
     NANO = HardwareGroup.COMMERCIAL_EDGE.value
