@@ -1,20 +1,28 @@
 from enum import Enum
+from typing import Optional, List
 
+from deci_common.abstractions.base_model import Schema
 from deci_common.data_types.enum.hardware_enums import InferenceHardware
 
 
+class FileExtensions(Schema):
+    main: str
+    additional: List[str] = []
+    raw: Optional[str] = None
+
+
 class FrameworkFileExtension(Enum):
-    TENSORFLOW1 = [".pb"]
-    TENSORFLOW2 = [".zip"]
-    PYTORCH = [".pth", ".pt"]
-    ONNX = [".onnx"]
-    TENSORRT = [".pkl"]
-    OPENVINO = [".pkl"]
-    TORCHSCRIPT = [".pth", ".pt"]
+    TENSORFLOW1 = FileExtensions(main=".pb")
+    TENSORFLOW2 = FileExtensions(main=".zip")
+    PYTORCH = FileExtensions(main=".pth", additional=[".pt"])
+    ONNX = FileExtensions(main=".onnx")
+    TENSORRT = FileExtensions(main=".pkl", raw=".engine")
+    OPENVINO = FileExtensions(main=".pkl", raw=".zip")
+    TORCHSCRIPT = FileExtensions(main=".pth", additional=[".pt"])
     TVM = None
-    KERAS = [".h5"]
-    TFLITE = [".tflite"]
-    COREML = [".mlmodel"]
+    KERAS = FileExtensions(main=".h5")
+    TFLITE = FileExtensions(main=".tflite")
+    COREML = FileExtensions(main=".mlmodel")
 
 
 class FrameworkType(str, Enum):
